################################
Tiny Desired State Configuration
################################

WARNING: Until version ``0.2``, *tdsc* should be considered unusably unstable.

*tdsc* is a lightweight "desired state configuration" library that aims to
make cross-machine configuration a pleasant experience.

********
Features
********

* Python support: ``2.7``, ``3.3+``
